package com.bocloud.sms.booter.controller;

import com.bocloud.sms.entity.Environment;
import com.bocloud.sms.interfaces.EnvironmentService;
import com.megatron.common.model.GeneralResult;
import com.megatron.common.model.GridBean;
import com.megatron.common.model.Pager;
import com.megatron.common.model.RequestContext;
import com.megatron.common.utils.Common;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.*;

/**
 * 环境实体类Controller
 *
 * @author wangshuai
 * @version 4.1.0-SNAPSHOT
 * @since 2018/12/24
 */
@RestController
@RequestMapping("/v1/environments")
@Tag(name = "所属环境")
public class EnvironmentController {
    private final EnvironmentService environmentService;

    public EnvironmentController(EnvironmentService environmentService) {
        this.environmentService = environmentService;
    }

    /**
     * 查看环境列表
     *
     * @param pager 分页参数
     * @return 环境列表
     */
    @Operation(summary = "获取所属环境列表")
    @GetMapping
    public GeneralResult<GridBean<Environment>> list(Pager pager, @Value(Common.REQ_CONTEXT) RequestContext context) {
        return environmentService.list(pager, context);
    }

    /**
     * 添加环境
     *
     * @param environment 环境
     * @param context     上下文
     * @return 添加结果
     */
    @Operation(summary = "添加所属环境")
    @PostMapping
    public GeneralResult<Environment> create(@RequestBody Environment environment,
                                             @Value(Common.REQ_CONTEXT) RequestContext context) {
        return environmentService.create(environment, context);
    }

    /**
     * 修改环境
     *
     * @param id          环境id
     * @param environment 环境
     * @param context     上下文
     * @return 修改结果
     */
    @Operation(summary = "修改所属环境")
    @PutMapping("/{id}")
    public GeneralResult<Environment> modify(@PathVariable(value = Common.ID) Long id, @RequestBody Environment environment,
                                             @Value(Common.REQ_CONTEXT) RequestContext context) {
        environment.setId(id);
        return environmentService.modify(environment, context);
    }

    /**
     * 删除环境
     *
     * @param id      环境id
     * @param context 上下文
     * @return 删除结果
     */
    @Operation(summary = "删除所属环境")
    @DeleteMapping("/{id}")
    public GeneralResult remove(@PathVariable(value = Common.ID) Long id,
                                @Value(Common.REQ_CONTEXT) RequestContext context) {
        return environmentService.remove(id, context);
    }

    /**
     * 查看环境明细
     *
     * @param id 环境id
     * @return 环境
     */
    @Operation(summary = "查看所属环境详情")
    @GetMapping("/{id}")
    public GeneralResult<Environment> detail(@PathVariable(value = Common.ID) Long id) {
        return environmentService.detail(id);
    }
}
