package com.bocloud.sms.booter.controller;

import com.bocloud.sms.entity.AccessLog;
import com.bocloud.sms.interfaces.LogService;
import com.megatron.common.model.*;
import com.megatron.common.utils.Common;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 审计日志控制器，用来进行平台审计日志的查询操作
 *
 * @author dmw
 */
@RestController
@RequestMapping("/v1/logs")
@Tag(name = "审计日志管理")
public class LogController {

    private final LogService logService;

    public LogController(LogService logService) {
        this.logService = logService;
    }

    /**
     * 审计日志查询
     *
     * @param pager 分页参数
     * @return 日志列表
     */
    @GetMapping
    @Operation(summary = "获取审计日志列表")
    public GeneralResult<GridBean<AccessLog>> list(Pager pager) {
        return this.logService.list(pager);

    }

    /**
     * 批量保存审计日志
     *
     * @param logs 审计日志数组
     * @return 保存结果
     */
    @Operation(summary = "批量保存审计日志")
    @PostMapping
    public Result batchSave(@RequestBody List<AccessLog> logs) {
        return this.logService.batch(logs);
    }

    /**
     * 审计日志归档
     *
     * @param startTime 开始时间
     * @param endTime   结束时间
     * @param deleted   是否删除
     * @param context   请求对象
     * @return
     */
    @GetMapping(value = "/archive")
    @Operation(summary = "审计日志归档")
    public GeneralResult<StringBuilder> archive(@RequestParam(value = "startTime", required = false) String startTime,
                                                @RequestParam(value = "endTime", required = false) String endTime,
                                                @RequestParam(value = "deleted", required = false) Boolean deleted,
                                                @Value(Common.REQ_CONTEXT) RequestContext context, HttpServletRequest request,
                                                HttpServletResponse response) {
        return logService.archive(startTime, endTime, deleted, context, request, response);
    }

}
