package com.bocloud.sms.booter.controller;

import com.bocloud.sms.entity.Message;
import com.bocloud.sms.interfaces.MessageService;
import com.megatron.common.model.*;
import com.megatron.common.utils.Common;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.*;

/**
 * @author tyl
 */
@RestController
@RequestMapping("/v1/messages")
@Tag(name = "消息管理")
public class MessageController {

    private final MessageService messageService;

    public MessageController(MessageService messageService) {
        this.messageService = messageService;
    }

    /**
     * 获取消息列表
     *
     * @param pager   分页对象
     * @param context 请求对象
     * @return 消息列表
     */
    @GetMapping
    @Operation(summary = "获取消息列表")
    public GeneralResult<GridBean<Message>> list(Pager pager, @Value(Common.REQ_CONTEXT) RequestContext context) {
        return messageService.list(pager, context);
    }

    /**
     * 删除消息
     *
     * @param id      消息id
     * @param context 请求对象
     * @return 删除结果
     */
    @DeleteMapping("/{id}")
    @Operation(summary = "删除消息")
    public Result remove(@PathVariable(value = Common.ID) Long id,
                         @Value(Common.REQ_CONTEXT) RequestContext context) {
        return messageService.remove(id, context.getTarget());
    }

    /**
     * 消息详情
     *
     * @param id      消息id
     * @param context 请求对象
     * @return 消息详情
     */
    @GetMapping("/{id}")
    @Operation(summary = "获取消息详情")
    public GeneralResult<Message> detail(@PathVariable(value = Common.ID) Long id,
                                         @Value(Common.REQ_CONTEXT) RequestContext context) {
        return messageService.detail(id, context);
    }

    /**
     * 当前用户消息状态全部更新为已读
     *
     * @param context 请求对象
     * @return 更新结果
     */
    @PatchMapping
    @Operation(summary = "更改消息状态")
    public Result readAll(@Value(Common.REQ_CONTEXT) RequestContext context) {
        return messageService.messageRead(context);
    }

    /**
     * 统计当前用户消息的状态数量
     *
     * @param context 请求对象
     * @return 状态数量
     */
    @GetMapping(value = "/stats")
    @Operation(summary = "统计消息数量")
    public GeneralResult<Message> statistics(@Value(Common.REQ_CONTEXT) RequestContext context) {
        return messageService.statistics(context);
    }
}
