package com.bocloud.sms.interfaces;

import com.bocloud.sms.entity.Message;
import com.megatron.common.model.*;

import java.util.Map;

/**
 * 消息服务接口
 *
 * @author weiwei
 * @version 1.0
 * @since 2016.10.26
 */
public interface MessageService {

    /**
     * 获取分页信息
     *
     * @param pager   分页参数
     * @param context 请求对象
     * @return 满足条件的列表
     */
    GeneralResult<GridBean<Message>> list(Pager pager, RequestContext context);

    /**
     * 添加
     *
     * @param context
     * @param title
     * @param content
     * @return
     */
    Result create(RequestContext context, String title, String content);

    /**
     * 移除
     *
     * @param id     ID
     * @param userId 操作者ID
     * @return 操作结果
     */
    Result remove(Long id, Long userId);

    /**
     * 获取详细信息
     *
     * @param id      ID
     * @param context 操作者ID
     * @return 操作结果
     */
    GeneralResult<Message> detail(Long id, RequestContext context);

    /**
     * 当前用户消息状态全部更新为已读
     *
     * @param context
     * @return
     */
    Result messageRead(RequestContext context);

    /**
     * 统计当前用户消息的状态数量
     *
     * @param context
     * @return
     */
    GeneralResult<Message> statistics(RequestContext context);

    /**
     * 发送队列消息
     *
     * @param queueName
     * @param message
     */
    void sendQueueMessage(String queueName, Map<String, Object> message);

}
