package com.bocloud.sms.service.utils;

import com.megatron.framework.core.CurrentService;
import com.bocloud.sms.entity.SystemConfig;
import com.bocloud.sms.repository.SystemConfigRepository;
import com.megatron.common.encrypt.DESEncryptor;
import com.megatron.framework.lock.AutoCloseLock;
import com.megatron.framework.lock.LockFactory;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.InitializingBean;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.scheduling.concurrent.ThreadPoolTaskExecutor;
import org.springframework.stereotype.Component;
import org.springframework.util.Assert;
import org.springframework.util.StringUtils;

import java.util.concurrent.TimeUnit;

/**
 * 定时同步数据类
 *
 * @author weiwei
 */
@Component
@Slf4j
public class SyncScheduler implements InitializingBean {

    private final SystemConfigRepository systemConfigRepository;
    private final LockFactory lockFactory;
    private final CurrentService currentService;
    private final ThreadPoolTaskExecutor taskExecutor;

    public SyncScheduler(SystemConfigRepository systemConfigRepository, LockFactory lockFactory, CurrentService currentService,
                         ThreadPoolTaskExecutor taskExecutor) {
        this.systemConfigRepository = systemConfigRepository;
        this.lockFactory = lockFactory;
        this.currentService = currentService;
        this.taskExecutor = taskExecutor;
    }

    @Scheduled(cron = "${ldap.sync.schedule:0 0 0 * * ?}")
    public void sync() {
        if (currentService.isLeader()) {
            taskExecutor.execute(this::execute);
        }
    }

    private void execute() {
        String path = "ldapLock";
        try (AutoCloseLock acLock = lockFactory.getACLock(path)) {
            Assert.isTrue(acLock.acquire(10, TimeUnit.SECONDS), "请求超时");
            SystemConfig urlConfig = systemConfigRepository.queryByCode("LdapUrl");
            if (null == urlConfig || !StringUtils.hasText(urlConfig.getValue())) {
                return;
            }
            SystemConfig userConfig = systemConfigRepository.queryByCode("LdapUsername");
            if (null == userConfig || !StringUtils.hasText(userConfig.getValue())) {
                return;
            }
            SystemConfig pswdConfig = systemConfigRepository.queryByCode("LdapPassword");
            if (null == pswdConfig || !StringUtils.hasText(pswdConfig.getValue())) {
                return;
            }
            SystemConfig baseConfig = systemConfigRepository.queryByCode("LdapBaseDn");
            if (null == baseConfig || !StringUtils.hasText(baseConfig.getValue())) {
                return;
            }
            LdapConfig config = new LdapConfig(urlConfig.getValue(), userConfig.getValue(), new DESEncryptor().decrypt(pswdConfig.getValue(), "BocloudCMP"),
                    baseConfig.getValue());
//            new LdapTransportor(managerRepository, departmentRepository, accountSecurityRepository, config).sync();
        } catch (Exception e) {
            log.error("ldap sync error.");
        }
    }

    @Override
    public void afterPropertiesSet() {
//        if (currentService.isLeader()) {
//            taskExecutor.execute(this::execute);
//        }
    }

}
