package com.bocloud.sms.repository;

import com.bocloud.sms.entity.Favorite;
import com.megatron.common.exception.DataBaseException;
import com.megatron.common.model.RequestContext;
import com.megatron.common.utils.MapTools;
import com.megatron.database.core.intf.impl.BasicGenericDao;
import com.megatron.framework.core.CurrentService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.namedparam.NamedParameterJdbcTemplate;
import org.springframework.stereotype.Repository;

import java.util.HashMap;
import java.util.Map;

/**
 * 操作收藏夹
 *
 * @author hya
 * @since 2022-03-02
 */
@Repository
public class FavoriteRepository extends BasicGenericDao<Favorite, Long> {

    @Autowired
    public FavoriteRepository(JdbcTemplate jdbcTemplate, NamedParameterJdbcTemplate npJdbcTemplate, CurrentService service) {
        super(jdbcTemplate, npJdbcTemplate, service);
    }

    /**
     * 取消收藏
     *
     * @param serviceId
     * @param userId
     * @return
     */
    public boolean cancelFavorite(Long serviceId, Long userId,String category) throws DataBaseException {
        String sql = "delete from favorite where category = :category ";
        Map<String, Object> paramsMap = new HashMap<>();
        paramsMap.put("category", category);
        if (userId != null && userId != 0L) {
            sql += "and target = :userId ";
            paramsMap.put("userId", userId);
        }
        if (serviceId != null && serviceId != 0L) {
            sql += "and service_id = :serviceId ";
            paramsMap.put("serviceId", serviceId);
        }
        return super.execute(sql, paramsMap) > 0;
    }

    /**
     * 修改收藏夹排序顺序
     *
     * @param serviceId
     * @param priority
     * @param userId
     * @return
     */
    public boolean changePriority(Long serviceId, Integer priority, Long userId) throws DataBaseException {
        String sql = "update favorite set priority = :priority where service_id=:serviceId and target=:userId and category='User' ";
        Map<String, Object> paramsMap = MapTools.simpleMap("serviceId", serviceId);
        paramsMap.put("priority", priority);
        paramsMap.put("userId", userId);
        return super.execute(sql, paramsMap) > 0;
    }
}
