package com.bocloud.sms.repository;

import com.bocloud.sms.entity.Icon;
import com.megatron.common.model.Pager;
import com.megatron.common.model.Param;
import com.megatron.common.utils.Common;
import com.megatron.common.utils.MapTools;
import com.megatron.database.core.intf.impl.BasicGenericDao;
import com.megatron.database.utils.QueryBuilder;
import com.megatron.framework.core.CurrentService;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.namedparam.NamedParameterJdbcTemplate;
import org.springframework.stereotype.Repository;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * 图表dao层实现类
 *
 * @author lyy
 * @Version 1.0
 * @since 2017年9月28日
 */
@Repository
public class IconRepository extends BasicGenericDao<Icon, Long> {

    public IconRepository(JdbcTemplate jdbcTemplate, NamedParameterJdbcTemplate npJdbcTemplate, CurrentService service) {
        super(jdbcTemplate, npJdbcTemplate, service);
    }

    public List<Icon> all() throws Exception {
        String sql = "select * from icon where is_deleted = 0";
        return this.list(Icon.class, sql, null);
    }

    public List<Icon> list(Pager pager) throws Exception {
        String sql = "select a.* from icon a where 1=1 and a.is_deleted = 0 ";
        sql = getQueryBuilder().buildRaw(sql, pager, "a");
        Map<String, Object> paramMap = getQueryBuilder().getParam(pager.getParams());
        return this.list(Icon.class, sql, paramMap);
    }

    public Icon query(Long id) throws Exception {
        String sql = "select * from icon where id = :id and is_deleted = 0";
        Map<String, Object> params = MapTools.simpleMap(Common.ID, id);
        List<Icon> icons = this.list(Icon.class, sql, params);
        if (icons.isEmpty()) {
            return null;
        }
        return icons.get(0);
    }

    public boolean delete(Long id) throws Exception {
        String sql = "update icon set is_deleted = 1 , gmt_modify = :gmtModify  where id = :id";
        Map<String, Object> params = MapTools.simpleMap(Common.ID, id);
        params.put("gmtModify", new Date());
        return this.execute(sql, params) > 0;
    }

    public int count(List<Param> params) throws Exception {
        String sql = "select count(1) from icon where is_deleted = 0";
        sql = getQueryBuilder().buildRaw(sql, params, null, "");
        Map<String, Object> param = getQueryBuilder().getParam(params);
        return this.countQuery(sql, param).intValue();
    }
}
