package com.bocloud.sms.repository;

import com.megatron.database.core.intf.impl.BasicGenericDao;
import com.bocloud.sms.entity.RolePermission;
import com.megatron.common.exception.DataBaseException;
import com.megatron.common.utils.MapTools;
import com.megatron.framework.core.CurrentService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.namedparam.NamedParameterJdbcTemplate;
import org.springframework.stereotype.Repository;

import java.util.List;
import java.util.Map;


/**
 * 角色权限关系
 *
 * @author hya
 * @since 2022-03-02
 */
@Repository
@Slf4j
public class RolePermissionRepository extends BasicGenericDao<RolePermission, Long> {

    @Autowired
    public RolePermissionRepository(JdbcTemplate jdbcTemplate, NamedParameterJdbcTemplate npJdbcTemplate, CurrentService service) {
        super(jdbcTemplate, npJdbcTemplate, service);
    }

    /**
     * 根据角色ID查询角色权限
     *
     * @param roleId
     * @return
     * @throws DataBaseException
     */
    public List<RolePermission> listPermission(Long roleId) throws DataBaseException {
        String sql = "select * from role_permission where role_id = :roleId";
        Map<String, Object> params = MapTools.simpleMap("roleId", roleId);
        return super.list(RolePermission.class, sql, params);
    }

    /**
     * 根据角色ID删除角色权限
     *
     * @param roleId
     * @return
     * @throws DataBaseException
     */
    public boolean unBindPermission(Long roleId) throws DataBaseException {
        String sql = "delete from role_permission where role_id = :roleId";
        Map<String, Object> params = MapTools.simpleMap("roleId", roleId);
        return super.execute(sql, params) > 0;
    }

    /**
     * 根据权限ID批量删除角色权限
     *
     * @param permissionIds
     * @return
     * @throws DataBaseException
     */

    public boolean unBindRole(List<Long> permissionIds) throws DataBaseException {
        String sql = "delete from role_permission where permission_id in (:permissionIds)";
        Map<String, Object> params = MapTools.simpleMap("permissionIds", permissionIds);
        return super.execute(sql, params) > 0;
    }


    /**
     * 批量插入角色权限
     *
     * @param rolePermissions
     * @throws DataBaseException
     */
    public boolean bindPermissions(List<RolePermission> rolePermissions) {
        try {
            StringBuilder sql = new StringBuilder("insert into role_permission(role_id, permission_id) values ");
            for (int i = 0; i < rolePermissions.size(); i++) {
                sql.append("(").append(rolePermissions.get(i).getRoleId())
                        .append(", ")
                        .append(rolePermissions.get(i).getPermissionId())
                        .append(")");
                if (i < rolePermissions.size() - 1) {
                    sql.append(", ");
                }
            }
            super.execute(sql.toString());
            return true;
        } catch (Exception e) {
            log.error(" 批量插入角色权限异常", e);
            return false;
        }
    }

}
